#!/usr/bin/Rscript
args <- commandArgs(T)
resFile <- args[1]
qcFile <- args[2]
varLim <- args[3]
dpLim <- args[4]
quants <- args[5]
output <- args[6]

read.delim(resFile, header=T) -> d
read.delim(qcFile, header=T) -> qc

# Calculate errorrate per amplicon
amps <- unique(qc$X.amp)
for (i in amps) {
	sel <- qc$X.amp == amps
	prob <- sum(qc$nVar[sel]) / (sum(qc$nRef) + sum(qc$nVar))
	pees <- pbinom(qc$nVar[sel], qc$nRef + qc$nVar, prob, lower.tail=F)
	Qscore <- -10 * log10(pees)
	
}

quantile(d$vaf, as.numeric(quants), na.rm=T) -> vafCut

sel1 <- d$vaf > vafCut
sel2 <- d$dp > dpLim
sel3 <- d$dpvar > varLim

sel <- sel1 & sel2 & sel3
write.table(d[sel,], paste(output, "res.f1.tsv", sep="."), row.names=F, col.names=T, quote=F, sep="\t")

dir.create(output)
setwd(output)

png(paste(output, "vafcut", "png", sep="."))
plot(density(log10(d$vaf), na.rm=T), main=paste("VAF cutoff", vafCut, sep=" "))
abline(v=log10(vafCut), col=2) 
dev.off()
